@@ -22,7 +22,7 @@ class OptionsManager(object):
         """初始化，读取配置文件，如没有设置临时文件夹，则设置并新建  \n
         :param path: ini文件的路径，默认读取模块文件夹下的
         """
-        self.ini_path = r'.\configs.ini' if path == 'default' or path is None else path
+        self.ini_path = str(Path(__file__).parent / 'configs.ini') if path == 'default' or path is None else path
         self._conf = RawConfigParser()
         self._conf.read(self.ini_path, encoding='utf-8')
 
@@ -31,9 +31,9 @@ class OptionsManager(object):
         self._session_options = None
 
         if 'tmp_path' not in self.paths or not self.get_value('paths', 'tmp_path'):
-            tmp_path = Path(r'.\tmp').absolute()
-            tmp_path.mkdir(parents=True, exist_ok=True)
-            self.set_item('paths', 'tmp_path', str(tmp_path))
+            tmp_path = str((Path(__file__).parent / 'tmp').absolute())
+            Path(tmp_path).mkdir(parents=True, exist_ok=True)
+            self.set_item('paths', 'tmp_path', tmp_path)
             self.save(self.ini_path)
 
     def __text__(self) -> str:
@@ -115,7 +115,7 @@ class OptionsManager(object):
         :return: 当前对象
         """
         if path == 'default':
-            path = Path(r'.\configs.ini').absolute()
+            path = (Path(__file__).parent / 'configs.ini').absolute()
         elif path is None:
             path = Path(self.ini_path).absolute()
         else:
@@ -149,7 +149,7 @@ class SessionOptions(object):
         self._max_redirects = None
 
         if read_file:
-            self.ini_path = ini_path or r'.\configs.ini'
+            self.ini_path = ini_path or str(Path(__file__).parent / 'configs.ini')
             om = OptionsManager(self.ini_path)
             options_dict = om.session_options
 
@@ -398,7 +398,7 @@ class SessionOptions(object):
         :return: 返回当前对象
         """
         if path == 'default':
-            path = Path(r'.\configs.ini').absolute()
+            path = (Path(__file__).parent / 'configs.ini').absolute()
         elif path is None:
             path = Path(self.ini_path).absolute()
         else:
@@ -409,7 +409,7 @@ class SessionOptions(object):
         if path.exists():
             om = OptionsManager(str(path))
         else:
-            om = OptionsManager(self.ini_path or r'.\configs.ini')
+            om = OptionsManager(self.ini_path or str(Path(__file__).parent / 'configs.ini'))
 
         options = _session_options_to_dict(self)
 
@@ -440,7 +440,7 @@ class DriverOptions(Options):
         self.ini_path = None
 
         if read_file:
-            self.ini_path = ini_path or r'.\configs.ini'
+            self.ini_path = ini_path or str(Path(__file__).parent / 'configs.ini')
             om = OptionsManager(self.ini_path)
             options_dict = om.chrome_options
 
@@ -465,7 +465,7 @@ class DriverOptions(Options):
         :return: 当前对象
         """
         if path == 'default':
-            path = Path(r'.\configs.ini').absolute()
+            path = (Path(__file__).parent / 'configs.ini').absolute()
         elif path is None:
             path = Path(self.ini_path).absolute()
         else:
@@ -476,7 +476,7 @@ class DriverOptions(Options):
         if path.exists():
             om = OptionsManager(str(path))
         else:
-            om = OptionsManager(self.ini_path or r'.\configs.ini')
+            om = OptionsManager(self.ini_path or str(Path(__file__).parent / 'configs.ini'))
 
         options = self.as_dict()
 
